==> racer-0.1.1.tgz: package/lib/mixin.ot/index.js <==
var Field, ot;
Field = require('./Field');
ot = module.exports = {
  init: function() {
    this.otFields = {};
    return this.on('setPost', function(_arg, ver) {
      var path, value;
      path = _arg[0], value = _arg[1];
      if (ver && value && value.$ot) {
        return this._otField(path).specTrigger(true);
      }
    });
  },
  accessors: {
    get: {
      type: 'basic',
      fn: function(path) {
        var val;
        val = this._adapter.get(path, this._specModel());
        if (val && (val.$ot != null)) {
          return this._otField(path, val).snapshot;
        }
        return val;
      }
    }
  },
  mutators: {
    insertOT: {
      type: 'ot',
      fn: function(path, pos, text, callback) {
        var op;
        op = [
          {
            p: pos,
            i: text
          }
        ];
        this._otField(path).submitOp(op, callback);
      }
    },
    delOT: {
      type: 'ot',
      fn: function(path, pos, len, callback) {
        var del, field, op;
        field = this._otField(path);
        del = field.snapshot.substr(pos, len);
        op = [
          {
            p: pos,
            d: del
          }
        ];
        field.submitOp(op, callback);
        return del;
      }
    }
  },
  proto: {
    ot: function(initVal) {
      return {
        $ot: initVal || ''
      };
    },
    isOtPath: function(path) {
      return this._adapter.get(path, this._specModel()).$ot !== void 0;
    },
    isOtVal: function(val) {
      return !!(val && val.$ot);
    },
    version: function(path) {
      return this.otFields[path].version;
    },
    _otField: function(path, val) {
      var field;
      path = this._dereference(path);
      if (field = this.otFields[path]) {
        return field;
      }
      field = this.otFields[path] = new Field(this, path);
      val || (val = this._adapter.get(path, this._specModel()));
      field.snapshot = val && val.$ot || '';
      return field;
    }
  },
  setupSocket: function(socket) {
    var adapter, model, otFields;
    otFields = this.otFields;
    adapter = this._adapter;
    model = this;
    return socket.on('otOp', function(_arg) {
      var field, op, path, v;
      path = _arg.path, op = _arg.op, v = _arg.v;
      if (!(field = otFields[path])) {
        field = otFields[path] = new Field(model, path);
        return field.specTrigger().on(function() {
          var val;
          val = adapter.get(path, model._specModel());
          field.snapshot = (val != null ? val.$ot : void 0) || '';
          return field.onRemoteOp(op, v);
        });
      } else {
        return field.onRemoteOp(op, v);
      }
    });
  }
};

==> racer-0.1.3.tgz: package/lib/mixin.ot/index.js <==
var Field, ot;

Field = require('./Field');

ot = module.exports = {
  init: function() {
    this.otFields = {};
    return this.on('setPost', function(_arg, ver) {
      var path, value;
      path = _arg[0], value = _arg[1];
      if (ver && value && value.$ot) return this._otField(path).specTrigger(true);
    });
  },
  accessors: {
    get: {
      type: 'basic',
      fn: function(path) {
        var val;
        val = this._adapter.get(path, this._specModel());
        if (val && (val.$ot != null)) return this._otField(path, val).snapshot;
        return val;
      }
    }
  },
  mutators: {
    insertOT: {
      type: 'ot',
      fn: function(path, pos, text, callback) {
        var op;
        op = [
          {
            p: pos,
            i: text
          }
        ];
        this._otField(path).submitOp(op, callback);
      }
    },
    delOT: {
      type: 'ot',
      fn: function(path, pos, len, callback) {
        var del, field, op;
        field = this._otField(path);
        del = field.snapshot.substr(pos, len);
        op = [
          {
            p: pos,
            d: del
          }
        ];
        field.submitOp(op, callback);
        return del;
      }
    }
  },
  proto: {
    ot: function(initVal) {
      return {
        $ot: initVal || ''
      };
    },
    isOtPath: function(path) {
      return this._adapter.get(path, this._specModel()).$ot !== void 0;
    },
    isOtVal: function(val) {
      return !!(val && val.$ot);
    },
    version: function(path) {
      return this.otFields[path].version;
    },
    _otField: function(path, val) {
      var field;
      path = this._dereference(path);
      if (field = this.otFields[path]) return field;
      field = this.otFields[path] = new Field(this, path);
      val || (val = this._adapter.get(path, this._specModel()));
      field.snapshot = val && val.$ot || '';
      return field;
    }
  },
  setupSocket: function(socket) {
    var adapter, model, otFields;
    otFields = this.otFields;
    adapter = this._adapter;
    model = this;
    return socket.on('otOp', function(_arg) {
      var field, op, path, v;
      path = _arg.path, op = _arg.op, v = _arg.v;
      if (!(field = otFields[path])) {
        field = otFields[path] = new Field(model, path);
        return field.specTrigger().on(function() {
          var val;
          val = adapter.get(path, model._specModel());
          field.snapshot = (val != null ? val.$ot : void 0) || '';
          return field.onRemoteOp(op, v);
        });
      } else {
        return field.onRemoteOp(op, v);
      }
    });
  }
};
